package com.takensoft.ai_lms.lms.word_book.web;

import com.takensoft.ai_lms.lms.word_book.service.WordBookService;
import com.takensoft.ai_lms.lms.word_book.vo.WordBookVO;
import lombok.RequiredArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.springframework.web.bind.annotation.*;

import java.util.List;
import java.util.Map;

/**
 * @author 권민수
 * @since 2024.07.29
 *
 * 단어장 정보 관련 컨트롤러 클래스
 */

@RestController
@RequiredArgsConstructor
@Slf4j
@RequestMapping("/wordbook")
public class WordBookController {

    final private WordBookService wordBookService;

    @GetMapping("/findAll.json")
    public List<WordBookVO> getAllWordBooks() {
        return wordBookService.getAllWordBooks();
    }

    @PostMapping("/find.json")
    public WordBookVO getWordBookById(@RequestBody WordBookVO wordBook) {
        return wordBookService.getWordBookById(wordBook.getWdBookId());
    }

    @PostMapping("/insert.json")
    public void insertWordBook(@RequestBody Map<String, String> req) {
        WordBookVO wordBook = new WordBookVO();
        wordBook.setWdBookTypeId(req.get("wdBookTypeId"));
        wordBook.setTextId(req.get("textId"));
        wordBook.setUserId(req.get("userId"));
        wordBookService.insertWordBook(wordBook);
    }

    @PutMapping("/update.json")
    public void updateWordBook(@RequestBody WordBookVO wordBook) {
        wordBookService.updateWordBook(wordBook);
    }

    @DeleteMapping("/delete.json")
    public void deleteWordBook(@RequestBody WordBookVO wordBook) {
        wordBookService.deleteWordBook(wordBook.getWdBookId());
    }

}
